# angular2-apollo

Use your GraphQL server data in your Angular 2.0 app, with the [Apollo Client](https://github.com/apollostack/apollo-client).

- [Boostrap][#bootstrap]
- [Inject][#inject]
- [ApolloQueryPipe](#apolloQueryPipe)

### Bootstrap
### Inject
### Bind to query

### ApolloQueryPipe

Apollo client exposes queries as observables, but each Apollo query can include few queries.

So inside an Apollo observable the data comes in the following form: `obs.data.queryName`

To handle that more easily we've created the `ApolloQueryPipe`. here is how it works:

```js
import {Component} from "angular2/core";
import {AsyncPipe} from "angular2/common";
import * as Apollo from "apollo-client/lib/src/index";
import {ApolloQueryPipe} from "./pipe";
import {Observable} from 'rxjs/Observable';

@Component({
  selector: 'postsList',
  templateUrl: 'client/postsList.html',
  pipes: [AsyncPipe, ApolloQueryPipe]
})
export class PostsList {
  posts: Observable<any[]>;

  constructor() {
    const networkInterface = Apollo.createNetworkInterface('http://localhost:8080');
    const client = new Apollo.default({
      networkInterface
    });

    this.posts = client.watchQuery({
      query: `
        query getPosts($tag: String) {
          posts(tag: $tag) {
            title
          }
        }
      `,
      variables: {
        tag: "1234"
      }
    });
  }
}
```

template:
```html
<ul>
  <li *ngFor="#post of posts | async | apolloQuery:'posts'">
      {{ post.title }}
  </li>
</ul>
```

We are pondering about a solution that will return an observable per single query and then we won't need that pipe anymore.

### Query parameters

### Mutations

### Development

Running tests locally:

```
# nvm use node
npm install
npm test
```

This project uses TypeScript for static typing and TSLint for linting. You can get both of these built into your editor with no configuration by opening this project in [Visual Studio Code](https://code.visualstudio.com/), an open source IDE which is available for free on all platforms.
